validate_enum_options

Function validate_enum_options 

fn validate_enum_options(
    options_map: &HashMap<String, String>,
    enum_tag_key: &str,
    enum_option_prefixes: &[&str],
) -> Result<bool>
Validates whether the options_map has valid options for specific enum_tag_key and returns true if the map contains the enum tag.

Variant options must start with one of enum_option_prefixes. If variant options are provided, the tagged enum type key must also be provided.